# -- ----------------------------------------
# -- This file contains analysis and plots 
#  
# -- Ben Depoorter, Lars Freund, and Sven Hoeppner
#    "The Moral Hazard Effect of Liquidated Damages: 
#    An Experiment on Contract Remedies"
#  
# -- author: Sven Hoeppner & Lars Freund
# -- file created: 20160518
# -- last file version: 20160727
# -- ----------------------------------------



# -- ------------------------------- -- #
# -- CODE CHUNK 1 "load-R-libraries" -- #

# -- This chunk loads all R-packages used.

library(ggplot2) # graphs & figures
library(scales) # scales in % for ggplot2
library(mfx) # marginal effects for probit and logit regressions
library(MASS) # ordered logit and ordered probit models
library(nnet) # multinomial logit and probit models
library(coin) # Wilcoxon Rank Sum that handles ties
library(exactRankTests)

 
# -- END CHUNK 1
# -- ------------------------------- -- #



# -- ------------------------ -- #
# -- CODE CHUNK 2 "load-data" -- #

# -- DESCRIPTION:
# -- This chunk loads the data.
# -- First, specify working directories.

# -- set working directory at wherever the consolidated dataset lies:
setwd("")

# -- load data
data.orig <- read.csv("DFH-data-consolidated-20160602.csv",
                      header = TRUE,
                      sep = ";",
                      dec = ".",
                      fill = TRUE
                      )

# -- END CHUNK 2
# -- ------------------------ -- #



# -- ------------------------------- -- #
# -- CODE CHUNK 3 "clean data frame" -- #

# -- variables that we don't need in the data frame?
vars.out <- !names(data.orig) %in% c("X1",
                                     "subjects",
                                     "Period",
                                     "TotalProfit",
                                     "Participate",
                                     "out_p",
                                     "out_a",
                                     "wage",
                                     "payoff_high",
                                     "payoff_low",
                                     "transfer_low",
                                     "transfer_high",
                                     "remedy.1",
                                     "transfer",
                                     "rand_transfer",
                                     "state_transfer",
                                     "prob",
                                     "group",
                                     "Umrechnung",
                                     "endowment_a",
                                     "endowment_aLOW",
                                     "N",
                                     "rand_rank",
                                     "random_group",
                                     "TimeWeiterIntroductionPartnerMatchingOK",
                                     "TimeOKInvestmentChoicePrincipalOK",
                                     "TimeOKEffortChoiceAgentOK",
                                     "rand_state",
                                     "TimeOKFeedbackPart1PrincipalOK",
                                     "TimeOKFeedbackPart1AgentOK",
                                     "TimeOKFeedbackPart1OK",
                                     "TimeWeiterBeginQuestionnaireOK",
                                     "TimeWeiterSociodemographicsOK",
                                     "TimeWeiterRiskAmbiguityStartOK",
                                     "TimeWeiterRiskOK",
                                     "TimeWeiterAmbiguityOK",
                                     "TimeOKStartSVOOK",
                                     "item_num",
                                     "LeaveStage",
                                     "TimeOKSVOItemsOK",
                                     "TimeKillSVOItemsOK",
                                     "TimeOKSummaryOK",
                                     "TimeOKFeedbackAgentPrincipalOK",
                                     "input_other [ item_num ]"
                                     )
# -- cleaner dataframe
data <- data.orig[,vars.out, drop = FALSE]

# -- END CHUNK 3
# -- ------------------------------- -- #



# -- ---------------------------- -- #
# -- CODE CHUNK 4 "add variables" -- #

# -- generate treatment variable
data$treatment <- ifelse(as.character(data$session) == "160518_0841" | as.character(data$session) == "160601_1247",
                         "BASE", 
                         ifelse(as.character(data$session) == "160518_0953" | as.character(data$session) == "160601_1130",
                                "NTT",
                                ifelse(as.character(data$session) == "160518_1141" | as.character(data$session) == "160601_1553",
                                       "FDT",
                                       ifelse(as.character(data$session) == "160518_1348" | as.character(data$session) == "160601_1413",
                                              "LDT",
                                              "RDT"
                                              )
                                       )
                                )
                         )

# -- generate treatment factor variable
data <- within(data, treatfact <- factor(treatment, levels=c("BASE", "NTT", "FDT", "LDT", "RDT")))

# -- generate treatment dummies
data$DVBASE <- ifelse(data$treatment == "BASE", 1, 0)
data$DVNTT <- ifelse(data$treatment == "NTT", 1, 0)
data$DVFDT <- ifelse(data$treatment == "FDT", 1, 0)
data$DVLDT <- ifelse(data$treatment == "LDT", 1, 0)
data$DVRDT <- ifelse(data$treatment == "RDT", 1, 0)

# -- generate effort factor variable
data$effort.f <- factor(data$effort, labels = c("1", "2", "3", "4", "5"))

# -- change sex from 1 (female) and 2 (male)
#                 to 0 (female) and 1 (male)
data$Sex <- ifelse(data$Sex == 2, 1, 0)

# -- END CHUNK 4
# -- ---------------------------- -- #



# -- ----------------------------------------- -- #
# -- CODE CHUNK 5 "analysis investment choice" -- #

# -- in this chunk we analyse player A's investment choice

# -- subset data to players A (Type = 1)
dataAs <- data[data$Type == 1, ]

# -- quick check of probability of invest == 1
length(dataAs$invest[which(dataAs$treatment == "BASE" & dataAs$invest == 1)])/length(dataAs$invest[which(dataAs$treatment == "BASE")])

# -- look at data
# -- plot probabilities of invest == 1 contingent on treatment
ggplot(dataAs, aes(x = as.factor(invest), fill = as.factor(invest))) + 
  geom_bar(aes(y = (..count..)/tapply(..count.., ..PANEL.., sum)[..PANEL..])) +
  scale_x_discrete(labels = c("no", "yes")) +
  scale_y_continuous(limits = c(0, 1), labels = percent) +
  facet_grid(.~treatfact) +
  xlab("invest") +
  ylab("frequency") +
  scale_fill_manual(values=c("#193F6EFF", "#193F6E8C")) +
  theme(
    legend.position="none",
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_rect(fill = "white"),
    strip.text.x = element_text(size = 10, colour = "#72747a"),
    strip.background = element_rect(fill = "#e1ebec"),
    axis.text.x = element_text(size = 10, colour = "#72747a"),
    axis.title.x = element_text(size = 12, vjust = 1.0),
    axis.text.y = element_text(size = 10, colour = "#72747a"),
    axis.title.y = element_text(size = 12, vjust = 0.0)
  )

# -- let's first look at a linear probability model
model01 <- lm(invest ~
                DVBASE +
                DVFDT +
                DVLDT +
                DVRDT +
                Age, # +
                # Sex +
                # svo_type, #+
                # RiskThreshold +
                # AmbThreshold,
              data = dataAs)
summary(model01)

# -- let's now look at a probit model
#    and it's average marginal effects 
model02 <- glm(invest ~ 
                 DVBASE +
                 DVFDT +
                 DVLDT +
                 DVRDT +
                 Age +
                 # Sex +
                 # svo_type +
                 # RiskThreshold +
                 AmbThreshold,
                 family = binomial(link = "probit"), 
                 data = dataAs
                 )
summary(model02)
model02mfx <- logitmfx(invest ~ 
                         DVBASE +
                         DVFDT +
                         DVLDT +
                         DVRDT +
                         Age +
                         # Sex +
                         # svo_type +
                         # RiskThreshold +
                         AmbThreshold,
                         data = dataAs,
                       atmean = FALSE)
model02mfx

# -- did all P's in LDT choose to implement the clause?
length(dataAs$clause[which(dataAs$clause == 1 & dataAs$treatment == "LDT")])/length(dataAs$treatment[which(dataAs$treatment == "LDT")])

# -- did A's choose to claim the remedy?
# -- 1: transfer claimed
# -- 0: transfer not claimed
# -- -1: transfer not necessary (because of high payoff)
dataAs$remedy[which(dataAs$treatment ==  "LDT")]
dataAs$remedy[which(dataAs$treatment ==  "FDT")]
dataAs$remedy[which(dataAs$treatment ==  "RDT")]

# -- END CHUNK 5
# -- ----------------------------------------- -- #



# -- ------------------------------------- -- #
# -- CODE CHUNK 6 "analysis effort choice" -- #

# -- in this chunk we analyse player B's effort choice

# -- subset data to players B (Type = 0)
dataBs <- data[data$Type == 0, ]

# -- look at data
# -- plot histograms of effort choices

# -- define color palatte first
blueshades <- c("#193f6e")
# -- add alpha values to color
add.alpha <- function(col, alpha = 1){
  if (missing(col))
    stop("Please provide a vector of colors.")
  apply(sapply(col, col2rgb)/255, 2,
        function(x)
          rgb(x[1], x[2], x[3], alpha = alpha)
        )
}
myblueshades <- add.alpha(blueshades, alpha = c(1.00, 0.85, 0.70, 0.55, 0.4))

ggplot(data = dataBs, aes(x = effort)) + 
  geom_histogram(aes(y = (..count..)/tapply(..count.., ..PANEL.., sum)[..PANEL..]),
                 binwidth = 1,
                 fill = "white") +
  # geom_density(alpha=.35, fill="#d7e58d") +
  facet_grid(.~treatfact) +
  geom_histogram(data = subset(dataBs, treatfact == "BASE"),
                 aes(y = (..count..)/tapply(..count.., ..PANEL.., sum)[..PANEL..]),
                 binwidth = 1,
                 colour="white",
                 fill = myblueshades) +
  geom_histogram(data = subset(dataBs, treatfact == "NTT"),
                 aes(y = (..count..)/tapply(..count.., ..PANEL.., sum)[..PANEL..]),
                 binwidth = 1,
                 colour="white",
                 fill = myblueshades) +
  geom_histogram(data = subset(dataBs, treatfact == "FDT"),
                 aes(y = (..count..)/tapply(..count.., ..PANEL.., sum)[..PANEL..]),
                 binwidth = 1,
                 colour="white",
                 fill = myblueshades) +
  geom_histogram(data = subset(dataBs, treatfact == "LDT"),
                 aes(y= (..count..)/tapply(..count.., ..PANEL.., sum)[..PANEL..]),
                 binwidth = 1,
                 colour="white",
                 fill = myblueshades) +
  geom_histogram(data = subset(dataBs, treatfact == "RDT"),
                 aes(y = (..count..)/tapply(..count.., ..PANEL.., sum)[..PANEL..]),
                 binwidth = 1,
                 colour="white",
                 fill = myblueshades) +
  xlab("effort choice contingent on treatment") +
  ylab("relative frequency") +
  scale_y_continuous(limits = c(0.00, 0.60),
                     breaks = c(0.00, 0.10, 0.20, 0.30, 0.40, 0.50, 0.60)) + 
  theme(
    legend.position="none",
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_rect(fill = "white"),
    strip.text.x = element_text(size = 10, colour = "#72747a"),
    strip.background = element_rect(fill = "#e1ebec"),
    axis.text.x = element_text(size = 10, colour = "#72747a"),
    axis.title.x = element_text(size = 12, vjust = 1.0),
    axis.text.y = element_text(size = 10, colour = "#72747a"),
    axis.title.y = element_text(size = 12, vjust = 0.0)
  )

# -- mean, median, standard deviation of effort choices
mean(dataBs$effort[which(dataBs$treatment == "BASE")])
mean(dataBs$effort[which(dataBs$treatment == "NTT")])
mean(dataBs$effort[which(dataBs$treatment == "FDT")])
mean(dataBs$effort[which(dataBs$treatment == "LDT")])
mean(dataBs$effort[which(dataBs$treatment == "RDT")])
median(dataBs$effort[which(dataBs$treatment == "BASE")])
median(dataBs$effort[which(dataBs$treatment == "NTT")])
median(dataBs$effort[which(dataBs$treatment == "FDT")])
median(dataBs$effort[which(dataBs$treatment == "LDT")])
median(dataBs$effort[which(dataBs$treatment == "RDT")])
sd(dataBs$effort[which(dataBs$treatment == "BASE")])
sd(dataBs$effort[which(dataBs$treatment == "NTT")])
sd(dataBs$effort[which(dataBs$treatment == "FDT")])
sd(dataBs$effort[which(dataBs$treatment == "LDT")])
sd(dataBs$effort[which(dataBs$treatment == "RDT")])

# -- start with hypothesis testing

# -- Hypothesis 1a
# -- use One-Way Permutation Test from coin package
x0 <- rep(x = 1, times = length(dataBs$effort[which(dataBs$treatment == "BASE")]))
x1 <- dataBs$effort[which(dataBs$treatment == "BASE")]
dat <- c(x0, x1)
fact <- c(rep("A", 32), rep("B", 32))
tab <- data.frame(cbind(dat,fact))
tab$dat <- as.numeric(as.character(tab$dat))
set.seed(10245)
oneway_test(dat~fact,
            data=tab,
            alternative="greater")

# -- Hypothesis 2a
# -- use One-Way Permutation Test from coin package
x0 <- dataBs$effort[which(dataBs$treatment == "BASE")]
x1 <- dataBs$effort[which(dataBs$treatment == "NTT")]
dat <- c(x0, x1)
fact <- c(rep("B", 32), rep("A", 30))
tab <- data.frame(cbind(dat,fact))
tab$dat <- as.numeric(as.character(tab$dat))
set.seed(10245)
oneway_test(dat ~ fact, data = tab,
            alternative = "greater",
            distribution = approximate(B = 9999))

# -- Hypothesis 3a
# -- use One-Way Permutation Test from coin package
x0 <- dataBs$effort[which(dataBs$treatment == "NTT")]
x1 <- dataBs$effort[which(dataBs$treatment == "FDT")]
dat <- c(x0, x1)
fact <- c(rep("B", 30), rep("A", 32))
tab <- data.frame(cbind(dat,fact))
tab$dat <- as.numeric(as.character(tab$dat))
set.seed(10245)
oneway_test(dat ~ fact, data = tab,
            alternative = "less",
            distribution = approximate(B = 9999))

# -- Hypothesis 4a
# -- use One-Way Permutation Test from coin package
x0 <- dataBs$effort[which(dataBs$treatment == "RDT")]
x1 <- dataBs$effort[which(dataBs$treatment == "FDT")]
dat <- c(x0, x1)
fact <- c(rep("A", 32), rep("B", 32))
tab <- data.frame(cbind(dat,fact))
tab$dat <- as.numeric(as.character(tab$dat))
set.seed(10245)
oneway_test(dat ~ fact,
            data = tab,
            alternative = "less",
            distribution = approximate(B = 9999))

# -- Hypothesis 5a
# -- use One-Way Permutation Test from coin package
x0 <- dataBs$effort_clause[which(dataBs$treatment == "LDT")]
x1 <- dataBs$effort[which(dataBs$treatment == "FDT")]
dat <- c(x0, x1)
fact <- c(rep("A", 31), rep("B", 32))
tab <- data.frame(cbind(dat,fact))
tab$dat <- as.numeric(as.character(tab$dat))
set.seed(10245)
oneway_test(dat ~ fact, data = tab,
            alternative = "less",
            conf.int = TRUE,
            conf.level = 0.95,
            distribution = approximate(B = 9999))


# -- we conduct pairwise tests again while controling for other variables
# -- to do so we run:
#    1) ordered probit regressions on variable effort.f
#    2) ROBUSTNESS (see code chunk 8): 
#       linear probability and logit on lowest effort levels 
#    3) ROBUSTNESS (see code chunk 8): 
#       linear probability and logit on highest effort levels 

# -- Hypothesis 1a
# -- subset treatments that we want to compare
subdata01 <- dataBs[which(dataBs$treatment == "BASE" | dataBs$treatment == "NTT"),]

# -- ordered probit regression model
model01 <- polr(effort.f ~ 
                  DVNTT +
                  # DVFDT +
                  # DVLDT +
                  # DVRDT +
                  Age +
                  # Sex +
                  svo_type + 
                  RiskThreshold +
                  AmbThreshold,
                data = subdata01,
                method = "probit",
                Hess = TRUE
                )
summary(model01)
# -- log likelihood of the model
logLik(model01)
# -- store coefficient table
coeftable01 <- coef(summary(model01))
# -- calculate and store p-values
p <- pnorm(abs(coeftable01[, "t value"]), lower.tail = FALSE) * 2
# -- combine with coefficient table
coeftable01 <- cbind(coeftable01, "p value" = p)
coeftable01
# -- some confident intervals
# ci <- confint(model01)
# confint.default(model01)

# -- convert the coefficients into odds ratios
# exp(coef(model01))
# exp(cbind(OddsRatio = coef(model01), ci))

# -- Hypothesis 2a
# -- subset treatments that we want to compare
subdata02 <- dataBs[which(dataBs$treatment == "FDT" | dataBs$treatment == "NTT"),]
# -- ordered logit regression model
model06 <- polr(effort.f ~ 
                  # DVNTT +
                  DVFDT +
                  # DVLDT +
                  # DVRDT +
                  # Age +
                  # Sex +
                  # svo_type +
                  RiskThreshold +
                  AmbThreshold,
                data = subdata02,
                method = "probit",
                Hess = TRUE
)
summary(model06)

# -- log likelihood of the model
logLik(model06)

# -- store coefficient table
coeftable02 <- coef(summary(model06))

# -- calculate and store p-values
p <- pnorm(abs(coeftable02[, "t value"]), lower.tail = FALSE) * 2

# -- combine with coefficient table
coeftable02 <- cbind(coeftable02, "p value" = p)
coeftable02

# -- Hypothesis 3a
# -- subset treatments that we want to compare
subdata03 <- dataBs[which(dataBs$treatment == "RDT" | dataBs$treatment == "FDT"),]
# -- ordered logit regression model
model11 <- polr(effort.f ~ 
                  # DVNTT +
                  # DVFDT +
                  # DVLDT +
                  DVRDT +
                  # Age +
                  # Sex +
                  svo_type +
                  RiskThreshold +
                  AmbThreshold,
                data = subdata03,
                method = "probit",
                Hess = TRUE
)
summary(model11)

# -- log likelihood of the model
logLik(model11)

# -- store coefficient table
coeftable04 <- coef(summary(model11))

# -- calculate and store p-values
p <- pnorm(abs(coeftable04[, "t value"]), lower.tail = FALSE) * 2

# -- combine with coefficient table
coeftable04 <- cbind(coeftable04, "p value" = p)
coeftable04

# -- Hypothesis 4a
# -- subset treatments that we want to compare
# -- generate effort factor variable
subdata04 <- dataBs[which(dataBs$treatment == "LDT" | dataBs$treatment == "FDT"),]
subdata04$effortclause.f <- ifelse(subdata04$treatment == "LDT",
                                 factor(subdata04$effort_clause, labels = c("1", "2", "3", "4", "5")),
                                 subdata04$effort.f)
subdata04$effortclause.f <- as.numeric(subdata04$effortclause.f)
subdata04$eff.fact <- factor(subdata04$effortclause.f)
# -- ordered logit regression model
model16 <- polr(eff.fact ~ 
                  # DVNTT +
                  # DVFDT +
                  DVLDT +
                  # DVRDT +
                  # Age +
                  # Sex +
                  svo_type +
                  RiskThreshold +
                  AmbThreshold,
                data = subdata04,
                method = "probit",
                Hess = TRUE
)
summary(model16)

# -- log likelihood of the model
logLik(model16)

# -- store coefficient table
coeftable05 <- coef(summary(model16))

# -- calculate and store p-values
p <- pnorm(abs(coeftable05[, "t value"]), lower.tail = FALSE) * 2

# -- combine with coefficient table
coeftable05 <- cbind(coeftable05, "p value" = p)
coeftable05

# -- END CHUNK 6
# -- ------------------------------------- -- #



# -- ----------------------------------------- -- #
# -- CODE CHUNK 7 "points earned in main task" -- #

# -- first look at players A ("player B") points in the main task
dataBBs <- data[data$Type == 0 & data$invest == 1, ]
mean(dataBBs$payoff1[which(dataAAs$treatment == "LDT")])
median(dataBBs$payoff1[which(dataAAs$treatment == "FDT")])
sd(dataBBs$payoff1[which(dataAAs$treatment == "FDT")])

# -- conduct permutation test to compare between treatments
pointsx <- dataBBs$payoff1[which(dataBBs$treatment == "FDT")]
pointsy <- dataBBs$payoff1[which(dataBBs$treatment == "LDT")]
dat <- c(pointsx, pointsy)
fact <- c(rep("A", length(pointsx)), rep("B", length(pointsy)))
tab <- data.frame(cbind(dat,fact))
tab$dat <- as.numeric(as.character(tab$dat))
set.seed(10245)
oneway_test(dat ~ fact, data = tab,
            alternative = "two.sided",
            conf.int = TRUE,
            conf.level = 0.95,
            distribution = approximate(B = 9999))


# -- now look at players P ("player A") points in the main task
dataAAs <- data[data$Type == 1 & data$invest == 1, ]
mean(dataAAs$payoff1[which(dataAAs$treatment == "LDT")])
median(dataAAs$payoff1[which(dataAAs$treatment == "LDT")])
sd(dataAAs$payoff1[which(dataAAs$treatment == "LDT")])

# -- conduct permutation test to compare between treatments
pointsx <- dataAAs$payoff1[which(dataAAs$treatment == "FDT")]
pointsy <- dataAAs$payoff1[which(dataAAs$treatment == "LDT")]
dat <- c(pointsx, pointsy)
fact <- c(rep("A", length(pointsx)), rep("B", length(pointsy)))
tab <- data.frame(cbind(dat,fact))
tab$dat <- as.numeric(as.character(tab$dat))
set.seed(10245)
oneway_test(dat ~ fact, data = tab,
            alternative = "two.sided",
            conf.int = TRUE,
            conf.level = 0.95,
            distribution = approximate(B = 9999))

# -- END CHUNK 7
# -- ----------------------------------------- -- #


# -- ------------------------------------- -- #
# -- CODE CHUNK 8 "robustness regressions" -- #

# -- this code chunk estimates regressions for the appendix
# -- goal is to find out which effort levels drive the 
#    significant effects of NTT and LDT 
#    observed in the ordered logit regression

# -- Effects of LDT versus FDT
# -- subset treatments that we want to compare
appdata01 <- dataBs[which(dataBs$treatment == "FDT" | dataBs$treatment == "LDT"),]

# -- The overall effect in LDT compared to FDT was negative in the ordered probit
# -- the idea for the robustness check is to check 
#    whether there is a negative treatment effect
#    for effort level 1 versus the rest
#    for effort levels (1,2) versus the rest
#    for effort levels (1,2,3) versus the rest
#    and so forth
# -- this way, we can see if the effect is driven by the lowest effort level
#    and when the significant negative effect stops

# -- generate a dummies for "low" effort
appdata01$loweff1 <- ifelse(appdata01$effort == 1, 
                            0, 
                            1)
appdata01$loweff2 <- ifelse(appdata01$effort == 1 | 
                              appdata01$effort == 2, 
                            0, 
                            1)
appdata01$loweff3 <- ifelse(appdata01$effort == 1 | 
                              appdata01$effort == 2 | 
                              appdata01$effort == 3, 
                            0, 
                            1)
appdata01$loweff4 <- ifelse(appdata01$effort == 1 | 
                              appdata01$effort == 2 | 
                              appdata01$effort == 3 |
                              appdata01$effort == 4, 
                            0, 
                            1)

# -- now run the regressions, changing the dependent variable for each
# -- first, linear probability models
appmod01 <- lm(loweff4 ~
                 DVLDT +
                 Age +
                 Sex +
                 svo_type +
                 RiskThreshold, # +
               # AmbThreshold,
               data = appdata01)
summary(appmod01)

# -- logit model and average marginal effects 
appmod02 <- glm(loweff4 ~
                  DVLDT +
                  Age +
                  Sex +
                  svo_type +
                  RiskThreshold +
                  AmbThreshold,
                family = binomial(link = "logit"),
                data = appdata01)
summary(appmod02)
appmod02mfx <- logitmfx(loweff4 ~
                          DVLDT +
                          Age +
                          Sex +
                          svo_type +
                          RiskThreshold +
                          AmbThreshold,
                        data = appdata01,
                        atmean = FALSE)
appmod02mfx

# -- Effects of NTT versus BASE
# -- subset treatments that we want to compare
appdata02 <- dataBs[which(dataBs$treatment == "BASE" | dataBs$treatment == "NTT"),]

# -- The overall effect in NTT compared to BASE was positive
#    in the ordered probit
# -- the idea for the robustness check is to check 
#    whether there is a positive treatment effect
#    for effort level 5 versus the rest
#    for effort levels (5,4) versus the rest
#    for effort levels (5,4,3) versus the rest
#    and so forth
# -- this way, we can see if the effect is driven by the highest effort level
#    and when the significant positive effect stops

# -- generate a dummies for "high" effort
appdata02$higheff1 <- ifelse(appdata02$effort == 5, 
                             1, 
                             0)
appdata02$higheff2 <- ifelse(appdata02$effort == 5 | 
                               appdata02$effort == 4, 
                             1, 
                             0)
appdata02$higheff3 <- ifelse(appdata02$effort == 5 | 
                               appdata02$effort == 4 | 
                               appdata02$effort == 3, 
                             1, 
                             0)
appdata02$higheff4 <- ifelse(appdata02$effort == 5 | 
                               appdata02$effort == 4 | 
                               appdata02$effort == 3 |
                               appdata02$effort == 2, 
                             1, 
                             0)

# -- now run the regressions, changing the dependent variable for each
# -- first, linear probability models
appmod03 <- lm(higheff4 ~
                 DVNTT +
                 Age +
                 # Sex +
                 # svo_type +
                 RiskThreshold +
                 AmbThreshold,
               data = appdata02)
summary(appmod03)

# -- logit model and average marginal effects 
appmod04 <- glm(higheff4 ~
                  DVNTT +
                  Age +
                  # Sex +
                  # svo_type +
                  RiskThreshold +
                  AmbThreshold,
                family = binomial(link = "logit"),
                data = appdata02)
summary(appmod04)
appmod04mfx <- logitmfx(higheff4 ~
                          DVNTT +
                          Age +
                          # Sex +
                          # svo_type +
                          RiskThreshold +
                          AmbThreshold,
                        data = appdata02,
                        atmean = FALSE)
appmod04mfx

# -- END CHUNK 8
# -- ------------------------------------- -- #